@@ -3,12 +3,13 @@ package Term::Highlight;
 require Exporter;
 
 use strict;
+use sort 'stable';
 
 our @ISA = qw( Exporter );
 
 our @EXPORT = qw( LoadArgs LoadPatterns ClearPatterns GetPatterns Process );
 
-our $VERSION = "1.6";
+our $VERSION = "1.7";
 
 
 sub new
@@ -91,7 +92,7 @@ sub LoadArgs
     }
     #push undefined pattern for last options not followed by any pattern
     #which will apply for the whole string
-    push @{ $self->{ Patterns } }, [ undef, $fgcolor, $bold ] if $lastPatternOmitted;
+    unshift @{ $self->{ Patterns } }, [ undef, $fgcolor, $bold ] if $lastPatternOmitted;
 }
 
 
@@ -135,11 +136,15 @@ sub FindPositionsOfTags
         }
         else
         {
+            #always mark the line matched in this case, perhaps with no tags
+            ++$result;
             my $length = length $$string_ref;
             next if $length == 0;
+            #trailing new lines cause problems: put the color tag before them
+            --$length if substr( $$string_ref, -1 ) eq "\n";
+            next if $length == 0;
             push @$positions, ( [ 0, $length, 1, $i, \$$patterns[ $i ] ],
                                 [ $length, $length, 0, $i, \$$patterns[ $i ] ] );
-            ++$result;
         }
     }
     $result;
@@ -293,14 +298,14 @@ Term::Highlight - Perl module to highlight regexp patterns on terminals
 
 =item $obj = Term::Highlight->new( tagtype => $TAGTYPE );
 
-=item $obj->LoadArgs( \@args );
-
 =item $obj->LoadPatterns( \@ptns );
 
-=item $obj->ClearPatterns( );
+=item $obj->LoadArgs( \@args );
 
 =item $obj->GetPatterns( );
 
+=item $obj->ClearPatterns( );
+
 =item $obj->Process( \$string );
 
 =back
@@ -326,14 +331,6 @@ expects a reference to an array of references to arrays of type
 [ $pattern, $fg, $bold, $bg ].
 Loads patterns to be processed.
 
-=item B<ClearPatterns>
-
-clears the loaded patterns.
-
-=item B<GetPatterns>
-
-returns a reference to the loaded patterns.
-
 =item B<LoadArgs>
 
 expects an array of references to strings.
@@ -341,6 +338,14 @@ Loads patterns to be processed.
 This is just a convenient version of C<LoadPatterns>.
 Example of array to be loaded: [ "-46", "-25.1", "-i", "\bw.*?\b", "-100" ].
 
+=item B<GetPatterns>
+
+returns a reference to the loaded patterns.
+
+=item B<ClearPatterns>
+
+clears the loaded patterns.
+
 =item B<Process>
 
 expects a reference to a string.
